@@ -9,10 +9,29 @@
 #include "dpkg.h"
 #include "usr_merge.h"
 
-void dpkg_start() {}
+void dpkg_start(const string& root_dir) {}
 void dpkg_end() {}
 
-static int read_dpkg_header(vector<string>& packages)
+int query(const char *path)
+{
+	// not implemented: diversions
+	FILE* fp;
+	setenv("LANG", "C", 1);
+	char buf[4000];
+	char *pos;
+
+	sprintf(buf, "dpkg-query --search '%s' 2>/dev/null", path);
+	if ((fp = popen(buf, "r")) == NULL) return 0;
+	if (!fgets(buf, sizeof(buf), fp)) return 0;
+	pos = strchr(buf, ':');
+	pos[0] = '\0';
+	pos = strchr(buf, ',');
+	if(pos) pos[0] = '\0';
+	puts(buf);
+	return 1;
+}
+
+int read_dpkg_header(vector<string>& packages)
 {
 	bool debug=getenv("DEBUG") != NULL;
 
@@ -147,7 +166,7 @@ static int read_dpkg_items(vector<string>& dpkg)
 	return 0;
 }
 
-int read_dpkg(vector<string>& packages, vector<string>& files, bool csv) {
+int read_dpkg(vector<string>& packages, vector<string>& files, bool csv, const string& root_dir) {
 	read_dpkg_header(packages);
 	read_dpkg_items(files);
 
